//
//  VKImageParameters.m
//
//  Copyright (c) 2013 VK.com
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy of
//  this software and associated documentation files (the "Software"), to deal in
//  the Software without restriction, including without limitation the rights to
//  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
//  the Software, and to permit persons to whom the Software is furnished to do so,
//  subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in all
//  copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
//  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
//  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
//  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
//  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#import "VKImageParameters.h"

@implementation VKImageParameters
+ (instancetype)pngImage {
	VKImageParameters *params = [VKImageParameters new];
	params.imageType = VKImageTypePng;
	return params;
}

+ (instancetype)jpegImageWithQuality:(float)quality {
	VKImageParameters *params = [VKImageParameters new];
	params.imageType = VKImageTypeJpg;
	params.jpegQuality = quality;
	return params;
}

- (NSString *)fileExtension {
	switch (self.imageType) {
		case VKImageTypeJpg:
			return @"jpg";
            
		case VKImageTypePng:
			return @"png";
            
		default:
			return nil;
	}
}

- (NSString *)mimeType {
	switch (self.imageType) {
		case VKImageTypeJpg:
			return @"image/jpeg";
            
		case VKImageTypePng:
			return @"image/png";
            
		default:
			return nil;
	}
}

@end
@implementation VKUploadImage
+ (instancetype)objectWithData:(NSData *)data andParams:(VKImageParameters *)params {
	VKUploadImage *image   = [VKUploadImage new];
	image.imageData         = data;
	image.parameters        = params;
	return image;
}

@end
